@@ -534,9 +534,7 @@ def createExecutables():
     with open(digicertFilePath, 'r') as file:
         data = file.read().replace('\n', '')
     printNicely(data+"digicert key", True)
-    changeDigicertKey=[CONST.DIGICERT_KEY, data]
-	
-    sedEquiv(bldCMD+CONST.TEMPLATE_EXT, bldCMD,[changeSignToolPath,changeWinInstallerPath,changeDigicertKey])
+    sedEquiv(bldCMD+CONST.TEMPLATE_EXT, bldCMD,[changeSignToolPath,changeWinInstallerPath ])
     mycmd.runCommandWithArgs([bldCMD, versionNumber,Non_Bruteforce_Agent,data,">>", logFileName])
     #if retval != 0 :
         #printNicely("Error in creating the exe file. please check console output to see error", False)
